@@ -3,7 +3,7 @@
 import logging
 import re
 import time
-from typing import List
+from typing import Any, List
 
 from metaloop.client.cloud_storage import CloudClient
 from metaloop.client.requests import Client
@@ -248,3 +248,21 @@ class MDS:
             secret_access_key,
             default_bucket
         )
+
+    def call_model_convert_path_status(self, data:Dict[str, Any]) -> None:
+        """callback modelConvert path and status.
+
+        Arguments:
+            data: The data of the requested json
+                mpid:  模型转换id
+                enc_way: 加密方式,
+                minio_path: minio模型转换路径,
+                ftp_path: ftp模型转换路径,
+                status: 转换状态
+                is_arm:  是否是arm模型 
+
+        """
+        if data.get("mpid") == None:
+             raise InvalidParamsError(message="mid not blank")
+        info = self._x_api.call_model_convert_path_status(data)
+        return info
