@@ -168,6 +168,21 @@ class X_API:
         response = self._client.open_api_do("POST", "search/tag", json=post_data)
         return response.json()
 
+    def list_objects(
+            self,
+            dataset_id: str,
+            offset: int = 0,
+            limit: int = 128,
+    ) -> Dict[str, Any]:
+        post_data: Dict[str, Any] = {
+            "offset": offset,
+            "limit": limit,
+            "dataset_id": [dataset_id]
+        }
+
+        response = self._client.open_api_do("POST", "search/dataset/object", json=post_data)
+        return response.json()
+
     def get_dataset_path(
             self,
             dataset_id: str,
